@@ -127,7 +127,7 @@ class GCCLikeToolchain(Toolchain):
         from pytools.prefork import call_capture_output
         result, stdout, stderr = call_capture_output([self.cc, "--version"])
         if result != 0:
-            raise RuntimeError("version query failed: "+stderrr)
+            raise RuntimeError("version query failed: "+stderr)
         return stdout
 
     def enable_debugging(self):
@@ -141,7 +141,7 @@ class GCCLikeToolchain(Toolchain):
                 [self.cc]
                 + ["-M"]
                 + ["-D%s" % define for define in self.defines]
-                + ["-U%s" % undefine for undefine in self.defines]
+                + ["-U%s" % undefine for undefine in self.undefines]
                 + ["-I%s" % idir for idir in self.include_dirs]
                 + self.cflags
                 + source_files
@@ -280,7 +280,7 @@ class NVCCToolchain(GCCLikeToolchain):
         numbers = words[4].split('.') + words[5].split('.')
 
         result = []
-        for n in number:
+        for n in numbers:
             try:
                 result.append(int(n))
             except ValueError:
@@ -374,6 +374,14 @@ def _guess_toolchain_kwargs_from_python_config():
         else:
             cflags.append(cflag)
 
+    # on Mac OS X, "libraries" can also be "frameworks"
+    libraries = []
+    for lib in make_vars["LIBS"].split():
+        if lib.startswith("-l"):
+            libraries.append(strip_prefix("-l", lib))
+        else:
+            cflags.append(lib)
+
     return dict(
             cc=cc_cmdline[0],
             ld=make_vars["LDSHARED"].split()[0],
@@ -382,8 +390,7 @@ def _guess_toolchain_kwargs_from_python_config():
                 make_vars["LDSHARED"].split()[1:]
                 + make_vars["LINKFORSHARED"].split()
                 ),
-            libraries=[strip_prefix("-l", lib)
-                for lib in make_vars["LIBS"].split()],
+            libraries=libraries,
             include_dirs=[
                 make_vars["INCLUDEPY"]
                 ],
